## MV Post Domestic Letter Bill Lookup

Find tracking number and # from Maldives Post Domestic Letter Bill.
![demo_ss.png](demo_ss.png)

### The Problem
Maldives Post delivery process currently faces an efficiency bottleneck:

1. Each mail bag comes with a printed delivery sheet containing multiple tracking numbers
2. Recipients need to locate their tracking number on this sheet to sign for their package
3. This is time-consuming because:
   - Tracking numbers are long (e.g., UV743594518UZ)
   - Multiple tracking numbers look very similar
   - The format mixes letters and numbers
   - The search process is prone to errors

### The Solution

This tool simplifies the delivery process by:
1. Converting the printed sheet lookup into a digital search
2. Allowing barcode scanning of tracking numbers
3. Instantly showing the corresponding sequence number (#)
4. Making it easy to find the right row on the printed sheet since sequence numbers are:
   - Short (1, 2, 3, etc.)
   - In numerical order
   - Easy for human eyes to scan quickly


## How to use
1. Upload spreadsheet provided by Maldives Post (contact Maldives Post for it)
2. Scan item bar code or manually enter tracking number
3. Find the Mail bag and # from printed sheet to sign


## Development
git clone and do whatever?
Requirements
- python 3.12+
- streamlit
- pandas
- openpyxl

Usage:
`pip install -r requirements.txt` \
`streamlit run app.py`

OR with docker \
`docker compose up --build`

## Deployment (with docker or podman compose)
1. save compose.yml
```yml
services:
  mvpost-package-no-finder:
    image: git.shihaam.dev/shihaam/mvpost-package-no-finder
    container_name: mvpost-package-no-finder
    ports:
      - "8501:8501"
    restart: always
```
2. `docker compose up -d`
3. enjoy.
